==> 1.1.1.tar.gz: lib/vcl.dart <==

library vcl;

import 'dart:async';
import 'dart:html';
import 'dart:math';

import 'package:sprintf/sprintf.dart';

part 'src/actnlist.dart';
part 'src/buttons.dart';
part 'src/classes.dart';
part 'src/comctrls.dart';
part 'src/commctrl.dart';
part 'src/comstrs.dart';
part 'src/consts.dart';
part 'src/controls.dart';
part 'src/dstring.dart';
part 'src/extctrls.dart';
part 'src/forms.dart';
part 'src/graphics.dart';
part 'src/grids.dart';
part 'src/mask.dart';
part 'src/menus.dart';
part 'src/rtlconsts.dart';
part 'src/stdactns.dart';
part 'src/stdctrls.dart';
part 'src/sysconst.dart';
part 'src/system.dart';
part 'src/systdate.dart';
part 'src/systobj.dart';
part 'src/sysmetric.dart';
part 'src/sysutils.dart';

part 'src/db.dart';
part 'src/dbconst.dart';
part 'src/dbgrids.dart';


part 'src/hwnd/HWND.dart';
part 'src/hwnd/hctrls.dart';

part 'src/hwnd/base.dart';
part 'src/hwnd/buttons.dart';
part 'src/hwnd/combobox.dart';
part 'src/hwnd/controls.dart';
part 'src/hwnd/edit.dart';
part 'src/hwnd/form.dart';
part 'src/hwnd/glyph.dart';
part 'src/hwnd/grid.dart';
part 'src/hwnd/groupbox.dart';
part 'src/hwnd/lblgroup.dart';
part 'src/hwnd/memo.dart';
part 'src/hwnd/menu.dart';
part 'src/hwnd/pagecontrol.dart';
part 'src/hwnd/popuplist.dart';
part 'src/hwnd/scroll.dart';
part 'src/hwnd/static.dart';
part 'src/hwnd/statusbar.dart';


part 'src/ext/CHAR.dart';
part 'src/ext/classes_ext.dart';
part 'src/ext/colors.dart';
part 'src/ext/convert.dart';
part 'src/ext/ctrls.dart';
part 'src/ext/date.dart';
part 'src/ext/dialogs.dart';
part 'src/ext/flxctrls.dart';
part 'src/ext/fmetric.dart';
part 'src/ext/gdi.dart';
part 'src/ext/html_ext.dart';
part 'src/ext/HDC.dart';
part 'src/ext/HIMAGE.dart';
part 'src/ext/locale.dart';
part 'src/ext/metric.dart';
part 'src/ext/mem.dart';
part 'src/ext/period.dart';
part 'src/ext/sysdate.dart';
part 'src/ext/systime.dart';
part 'src/ext/time.dart';
part 'src/ext/types_ext.dart';
part 'src/ext/winuser.dart';
part 'src/ext/windows.dart';



final String vcl_lib_version = '1.1.1';
final DateTime vcl_lib_date = DateTime(2022, 03, 11);

==> 1.2.0.tar.gz: lib/vcl.dart <==

library vcl;

import 'dart:async';
import 'dart:html';
import 'dart:math';

import 'package:sprintf/sprintf.dart';

part 'src/actnlist.dart';
part 'src/buttons.dart';
part 'src/classes.dart';
part 'src/comctrls.dart';
part 'src/commctrl.dart';
part 'src/comstrs.dart';
part 'src/consts.dart';
part 'src/controls.dart';
part 'src/dstring.dart';
part 'src/extctrls.dart';
part 'src/forms.dart';
part 'src/graphics.dart';
part 'src/grids.dart';
part 'src/mask.dart';
part 'src/menus.dart';
part 'src/rtlconsts.dart';
part 'src/stdactns.dart';
part 'src/stdctrls.dart';
part 'src/sysconst.dart';
part 'src/system.dart';
part 'src/systdate.dart';
part 'src/systobj.dart';
part 'src/sysmetric.dart';
part 'src/sysutils.dart';

part 'src/db.dart';
part 'src/dbconst.dart';
part 'src/dbgrids.dart';


part 'src/hwnd/hctrls.dart';
part 'src/hwnd/base.dart';
part 'src/hwnd/buttons.dart';
part 'src/hwnd/combobox.dart';
part 'src/hwnd/controls.dart';
part 'src/hwnd/edit.dart';
part 'src/hwnd/form.dart';
part 'src/hwnd/glyph.dart';
part 'src/hwnd/grid.dart';
part 'src/hwnd/groupbox.dart';
part 'src/hwnd/lblgroup.dart';
part 'src/hwnd/memo.dart';
part 'src/hwnd/menu.dart';
part 'src/hwnd/pagecontrol.dart';
part 'src/hwnd/popuplist.dart';
part 'src/hwnd/scroll.dart';
part 'src/hwnd/static.dart';
part 'src/hwnd/statusbar.dart';


part 'src/ext/CHAR.dart';
part 'src/ext/classes_ext.dart';
part 'src/ext/colors.dart';
part 'src/ext/convert.dart';
part 'src/ext/ctrls.dart';
part 'src/ext/date.dart';
part 'src/ext/dialogs.dart';
part 'src/ext/flxctrls.dart';
part 'src/ext/fmetric.dart';
part 'src/ext/gdi.dart';
part 'src/ext/html_ext.dart';
part 'src/ext/HDC.dart';
part 'src/ext/HIMAGE.dart';
part 'src/ext/locale.dart';
part 'src/ext/metric.dart';
part 'src/ext/mem.dart';
part 'src/ext/period.dart';
part 'src/ext/sysdate.dart';
part 'src/ext/systime.dart';
part 'src/ext/time.dart';
part 'src/ext/types_ext.dart';
part 'src/win/winuser.dart';

part 'src/win/HWND.dart';
part 'src/win/sysparams.dart';
part 'src/win/USER_Driver.dart';
part 'src/win/win.dart';
part 'src/win/window.dart';
part 'src/win/winpos.dart';
part 'src/win/windows.dart';
part 'src/win/WND.dart';



final String vcl_lib_version = '1.2.0';
final DateTime vcl_lib_date = DateTime(2022, 03, 29);
